import React from "/apps/websight-atlaskit-esm/web-resources/react.js";
import Button, { ButtonGroup } from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/button.js";
import ModalDialog, { ModalTransition } from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/modal-dialog.js";
import { Section } from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/menu.js";
import { Checkbox } from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/checkbox.js";
import Textfield from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/textfield.js";
import RestClient from "/apps/websight-rest-atlaskit-client/web-resources/js/RestClient.js";
import Form, { FormFooter } from "/apps/websight-rest-atlaskit-client/web-resources/js/Form.js";
import styled from "/apps/websight-atlaskit-esm/web-resources/styled-components.js";
const Message = styled.div`
    padding-top: 10px;
`;
export default class ResourcePublishModal extends React.PureComponent {
  constructor(props) {
    super(props);
    this.restClient = new RestClient('websight-aem-replication-support-service');
    this.state = {
      isOpen: false,
      resource: null,
      replicateChildren: false,
      displayWarning: false,
      submitDisabled: false
    };
    this.open = this.open.bind(this);
    this.close = this.close.bind(this);
    this.onFormSubmit = this.onFormSubmit.bind(this);
  }

  open(resource) {
    this.setState({
      isOpen: true,
      resource: resource,
      displayWarning: resource.path.split('/').length - 1 <= 3
    });
  }

  close() {
    this.setState({
      isOpen: false
    });
  }

  onFormSubmit(data) {
    const action = data.replicateChildren === true ? 'recursive-publish' : 'publish';
    this.restClient.post({
      action: action,
      data: {
        path: this.state.resource.path,
        type: 'resource'
      },
      always: () => {
        this.close();
      }
    });
  }

  render() {
    const {
      isOpen,
      submitDisabled,
      displayWarning,
      replicateChildren,
      resource
    } = this.state;
    return /*#__PURE__*/React.createElement(ModalTransition, null, isOpen && /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(ModalDialog, {
      onClose: this.close,
      width: "large",
      heading: "Publish resource"
    }, /*#__PURE__*/React.createElement(Form, {
      onSubmit: data => this.onFormSubmit(data),
      onSuccess: this.close
    }, ({
      submitted
    }) => /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Section, {
      hasSeparator: true
    }, /*#__PURE__*/React.createElement(Checkbox, {
      defaultChecked: false,
      hideLabel: true,
      label: 'Replicate children',
      name: "replicateChildren",
      onChange: e => {
        this.setState({
          replicateChildren: e.currentTarget.checked,
          submitDisabled: displayWarning && e.currentTarget.checked
        });
      }
    }), displayWarning && replicateChildren && /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Message, null, 'You are going to publish high level resource that potentially can have a lot of children'), /*#__PURE__*/React.createElement(Message, null, 'Type the following path to confirm: ', /*#__PURE__*/React.createElement("span", {
      style: {
        fontWeight: 'bold'
      }
    }, resource.path)), /*#__PURE__*/React.createElement(Textfield, {
      autoFocus: true,
      name: "resPath",
      label: "Resource path",
      isRequired: true,
      onChange: event => {
        this.setState({
          submitDisabled: resource.path !== event.target.value
        });
      }
    }))), /*#__PURE__*/React.createElement(FormFooter, null, /*#__PURE__*/React.createElement(ButtonGroup, null, /*#__PURE__*/React.createElement(Button, {
      appearance: "primary",
      autoFocus: true,
      type: "submit",
      isLoading: submitted,
      isDisabled: submitDisabled
    }, "Publish"), /*#__PURE__*/React.createElement(Button, {
      appearance: "subtle",
      onClick: this.close,
      isDisabled: submitted
    }, "Cancel"))))))));
  }

}