import React from "/apps/websight-atlaskit-esm/web-resources/react.js";
import Button, { ButtonGroup } from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/button.js";
import ModalDialog, { ModalTransition } from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/modal-dialog.js";
import { Section } from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/menu.js";
import { Checkbox } from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/checkbox.js";
import RestClient from "/apps/websight-rest-atlaskit-client/web-resources/js/RestClient.js";
import Form, { FormFooter } from "/apps/websight-rest-atlaskit-client/web-resources/js/Form.js";
import styled from "/apps/websight-atlaskit-esm/web-resources/styled-components.js";
const Message = styled.div`
    padding-top: 10px;
    padding-bottom: 10px;
`;
export default class UserPublicationModal extends React.PureComponent {
  constructor(props) {
    super(props);
    this.restClient = new RestClient('websight-aem-replication-support-service');
    this.state = {
      isOpen: false,
      publishGroups: new Set()
    };
    this.open = this.open.bind(this);
    this.close = this.close.bind(this);
    this.onFormSubmit = this.onFormSubmit.bind(this);
  }

  open() {
    this.setState({
      isOpen: true
    });
  }

  close() {
    this.setState({
      isOpen: false
    });
  }

  onFormSubmit() {
    this.restClient.post({
      action: 'user-publish',
      data: {
        path: this.props.user.path,
        type: 'user',
        publishGroups: Array.from(this.state.publishGroups)
      },
      always: () => {
        this.close();
      }
    });
  }

  render() {
    const {
      isOpen,
      publishGroups
    } = this.state;
    const {
      user
    } = this.props;
    return /*#__PURE__*/React.createElement(ModalTransition, null, isOpen && /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(ModalDialog, {
      onClose: this.close,
      heading: "Publish user",
      width: "large"
    }, /*#__PURE__*/React.createElement(Form, {
      onSubmit: data => this.onFormSubmit(data),
      onSuccess: this.close
    }, ({
      submitted
    }) => /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Section, {
      hasSeparator: true
    }, /*#__PURE__*/React.createElement(Message, null, 'Select groups to publish'), user.groups.map((group, index) => {
      return /*#__PURE__*/React.createElement(Checkbox, {
        key: index,
        defaultChecked: false,
        hideLabel: true,
        label: group.displayName,
        value: group.path,
        onChange: e => {
          if (e.currentTarget.checked) {
            publishGroups.add(e.currentTarget.value);
          } else {
            publishGroups.delete(e.currentTarget.value);
          }

          this.setState({
            publishGroups: publishGroups
          });
        }
      });
    })), /*#__PURE__*/React.createElement(FormFooter, null, /*#__PURE__*/React.createElement(ButtonGroup, null, /*#__PURE__*/React.createElement(Button, {
      autoFocus: true,
      appearance: "primary",
      type: "submit",
      isLoading: submitted
    }, "Publish"), /*#__PURE__*/React.createElement(Button, {
      appearance: "subtle",
      onClick: this.close,
      isDisabled: submitted
    }, "Cancel"))))))));
  }

}