function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from "/apps/websight-atlaskit-esm/web-resources/react.js";
import Button, { ButtonGroup } from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/button.js";
import Form, { ErrorMessage, Field, FormFooter } from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/form.js";
import TextField from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/textfield.js";
import { colors as atlaskitColors } from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/theme.js";
import styled from "/apps/websight-atlaskit-esm/web-resources/styled-components.js";
import { generateTheme } from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/atlassian-navigation.js";
import AuthContextProvider from "/apps/websight-rest-esm-client/web-resources/AuthContextProvider.js";
const HiddenField = styled.div`
    display: none;
`;
const theme = generateTheme({
  name: 'high-contrast',
  backgroundColor: atlaskitColors.B500,
  highlightColor: atlaskitColors.N0
});
export default class Login extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      targetPath: this.getTargetPath(),
      errorMessage: this.getErrorMessage()
    };
    this.asyncFormSubmit = this.asyncFormSubmit.bind(this);
  }

  getTargetPath() {
    const resource = this.getQueryStringParameter(window.location.href, 'resource');
    return resource ? resource : '/';
  }

  getErrorMessage() {
    const jReason = this.getQueryStringParameter(window.location.href, 'j_reason');

    if (jReason) {
      if (jReason === 'INVALID_CREDENTIALS') {
        return 'Invalid username or password';
      }

      return 'Authentication failed: ' + jReason;
    }

    return '';
  }

  getQueryStringParameter(url, parameter) {
    const params = new URLSearchParams(new URL(url).search);
    return params.get(parameter);
  }

  asyncFormSubmit(data) {
    const formData = new FormData();
    Object.keys(data).forEach(key => formData.append(key, data[key]));
    fetch('/j_security_check', {
      method: 'POST',
      redirect: 'manual',
      body: formData
    }).then(response => {
      if (response.status !== 403) {
        AuthContextProvider.checkAuthentication();
      } else {
        response.text().then(text => this.setState({
          errorMessage: text
        }));
      }
    });
  }

  render() {
    const {
      targetPath
    } = this.state;
    const {
      asyncSubmit
    } = this.props;
    return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Form, {
      onSubmit: data => {
        if (asyncSubmit) {
          this.asyncFormSubmit(data);
        } else {
          const form = document.querySelector('#login-form');
          form.submit();
        }
      }
    }, ({
      formProps,
      submitting
    }) => /*#__PURE__*/React.createElement("form", _extends({
      id: "login-form",
      method: "post",
      action: "j_security_check"
    }, formProps), /*#__PURE__*/React.createElement(HiddenField, null, /*#__PURE__*/React.createElement(Field, {
      name: "_charset_",
      defaultValue: "UTF-8"
    }, ({
      fieldProps
    }) => /*#__PURE__*/React.createElement(TextField, fieldProps))), /*#__PURE__*/React.createElement(HiddenField, null, /*#__PURE__*/React.createElement(Field, {
      name: "resource",
      defaultValue: targetPath
    }, ({
      fieldProps
    }) => /*#__PURE__*/React.createElement(TextField, fieldProps))), /*#__PURE__*/React.createElement(Field, {
      name: "j_username",
      label: "Username",
      isRequired: true,
      defaultValue: ""
    }, ({
      fieldProps,
      error
    }) => /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(TextField, _extends({
      autoComplete: "off"
    }, fieldProps)), error && /*#__PURE__*/React.createElement(ErrorMessage, null, "Invalid username or password."))), /*#__PURE__*/React.createElement(Field, {
      name: "j_password",
      label: "Password",
      defaultValue: "",
      isRequired: true
    }, ({
      fieldProps,
      error
    }) => /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(TextField, _extends({
      type: "password"
    }, fieldProps)), error && /*#__PURE__*/React.createElement(ErrorMessage, null, "Password needs to be more than 3 characters."))), this.state.errorMessage ? /*#__PURE__*/React.createElement("p", {
      style: {
        color: atlaskitColors.R400
      }
    }, this.state.errorMessage) : undefined, /*#__PURE__*/React.createElement(FormFooter, null, /*#__PURE__*/React.createElement(ButtonGroup, null, /*#__PURE__*/React.createElement(Button, {
      type: "submit",
      appearance: "primary",
      isLoading: submitting
    }, "Log in"))))));
  }

}