import React from "/apps/websight-atlaskit-esm/web-resources/react.js";
import { Container, Format } from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/badge.js";
import { ContainerHeader, GroupHeading, HeaderSection, Item, MenuSection } from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/navigation-next.js";
import styled from "/apps/websight-atlaskit-esm/web-resources/styled-components.js";
import { AvatarIcon } from "/apps/websight-admin/web-resources/Icons.js";
import { colors } from "/apps/websight-admin/web-resources/theme.js";
import { LoadingWrapper } from "/apps/websight-admin/web-resources/Wrappers.js";
import StatefulFilterInput from "/apps/websight-admin/web-resources/components/StatefulFilterInput.js";
import { PACKAGE_MANAGER_ROOT_PATH } from "../utils/PackageManagerConstants.js";
const GroupFilterInputContainer = styled.div`
    margin-bottom: 6px;
`;
const GroupsNotFoundContainer = styled.div`
    text-align: center;
    margin-top: 20px;
`;

const createBadge = (limitExceeded, count, bold) => {
  const badgeContent = /*#__PURE__*/React.createElement(Format, {
    max: limitExceeded ? count - 1 : null
  }, count);
  return /*#__PURE__*/React.createElement(Container, {
    backgroundColor: limitExceeded ? colors.red : colors.primaryBlue,
    textColor: colors.white
  }, bold ? /*#__PURE__*/React.createElement("b", null, badgeContent) : badgeContent);
};

export default class ContainerNavigation extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      groupNameFilter: this.props.groupNameFilter
    };
  }

  render() {
    const groupNameFilter = this.state.groupNameFilter;
    const groupNameFilterNotEmpty = groupNameFilter && groupNameFilter.length > 0;
    const groupsToDisplay = (this.props.groups || []).filter(group => groupNameFilterNotEmpty ? group.name.toLowerCase().includes(groupNameFilter.toLocaleLowerCase()) : !group.name.includes('/'));
    return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(HeaderSection, null, ({
      css
    }) => /*#__PURE__*/React.createElement("div", {
      style: { ...css,
        paddingBottom: 20
      }
    }, /*#__PURE__*/React.createElement(ContainerHeader, {
      before: () => /*#__PURE__*/React.createElement(AvatarIcon, {
        className: "material-icons"
      }, "dvr"),
      href: PACKAGE_MANAGER_ROOT_PATH,
      text: "Package Manager"
    }))), /*#__PURE__*/React.createElement(MenuSection, null, ({
      className
    }) => /*#__PURE__*/React.createElement("div", {
      className: className
    }, /*#__PURE__*/React.createElement(GroupHeading, null, "Groups"), /*#__PURE__*/React.createElement(GroupFilterInputContainer, null, /*#__PURE__*/React.createElement(StatefulFilterInput, {
      value: groupNameFilter,
      onChange: event => {
        const value = event.target.value;
        this.props.onGroupNameFilterChange(value);
        this.setState({
          groupNameFilter: value
        });
      },
      onClear: () => {
        this.props.onGroupNameFilterChange('');
        this.setState({
          groupNameFilter: ''
        });
      }
    })), /*#__PURE__*/React.createElement(LoadingWrapper, {
      isLoading: this.props.isLoadingGroups,
      spinnerStyle: {
        top: '30vh',
        bottom: 'auto'
      },
      spinnerSize: "large"
    }, (!groupNameFilter || groupNameFilter.length === 0) && /*#__PURE__*/React.createElement(Item, {
      text: /*#__PURE__*/React.createElement("b", null, "All packages"),
      isSelected: !this.props.selected,
      after: () => createBadge(this.props.limitExceeded, this.props.allPackagesCount, true),
      onClick: () => this.props.findPackages({
        group: null,
        pageNumber: 1
      })
    }), groupsToDisplay && groupsToDisplay.length > 0 ? groupsToDisplay.map(group => /*#__PURE__*/React.createElement(Item, {
      key: group.name,
      text: group.name === ':no_group' ? /*#__PURE__*/React.createElement("i", null, "No group") : group.name,
      isSelected: group.name === this.props.selected,
      after: () => createBadge(group.limitExceeded, group.count, false),
      onClick: () => this.props.findPackages({
        group: group.name,
        pageNumber: 1
      })
    })) : /*#__PURE__*/React.createElement(GroupsNotFoundContainer, null, "No groups found")))));
  }

}