import React from "/apps/websight-atlaskit-esm/web-resources/react.js";
import styled from "/apps/websight-atlaskit-esm/web-resources/styled-components.js";
import PathAutosuggestion from "/apps/websight-autosuggestion-esm/web-resources/PathAutosuggestion.js";
import { colors } from "/apps/websight-admin/web-resources/theme.js";
import ResourceProviderDotMarkerContainer from "../utils/ResourceProviderDotMarkerContainer.js";
const AutosuggestionContainer = styled.div`
    display: flex;
    width: 100%;
`;
const OptionLabelContainer = styled.div`
    display: flex;
    align-items: center;
    overflow: hidden;
`;
export default class ResourceHeader extends React.Component {
  constructor(props) {
    super(props);
    this.optionPostProcessor = this.optionPostProcessor.bind(this);
  }

  optionPostProcessor(option) {
    const {
      providers
    } = this.props;

    const removeBeginningSlashFromString = value => value[0] === '/' ? value.slice(1) : value;

    if (option.isDisabled) return {
      label: option.value,
      ...option
    };
    const optionHasProviders = option.data && option.data.providers && option.data.providers.length;
    const optionProviders = optionHasProviders ? option.data.providers : ['synthetic.resource'];

    const providerMarkerColor = provider => {
      if (optionHasProviders) {
        return providers.find(({
          value
        }) => value === provider).color;
      } else {
        return colors.grey;
      }
    };

    const providerLabel = provider => {
      if (optionHasProviders) {
        return providers.find(({
          value
        }) => value === provider).label;
      } else {
        return 'Synthetic Resource';
      }
    };

    const newOptionValue = removeBeginningSlashFromString(option.value);
    return { ...option,
      value: newOptionValue,
      label: /*#__PURE__*/React.createElement(OptionLabelContainer, null, newOptionValue, optionProviders.map(provider => {
        const color = providerMarkerColor(provider);
        return /*#__PURE__*/React.createElement(ResourceProviderDotMarkerContainer, {
          key: `${option.value}${provider}`,
          style: {
            background: color
          }
        }, providerLabel(provider));
      }))
    };
  }

  render() {
    const {
      providers,
      resource,
      openResourcesForPath
    } = this.props;
    return /*#__PURE__*/React.createElement(AutosuggestionContainer, null, /*#__PURE__*/React.createElement(PathAutosuggestion, {
      noOptionsMessage: inputValue => `No resource found for "${inputValue}"`,
      onChange: resourcePath => {
        openResourcesForPath(resourcePath);
      },
      optionPostProcessor: this.optionPostProcessor,
      parameters: {
        autosuggestionType: 'resource-browser',
        providers: providers.map(({
          value
        }) => value)
      },
      placeholder: "Choose a resource path",
      styles: {
        backgroundColor: colors.white
      },
      value: resource.path
    }));
  }

}