function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from "/apps/websight-atlaskit-esm/web-resources/react.js";
import TextField from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/textfield.js";
import Tooltip from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/tooltip.js";
import styled from "/apps/websight-atlaskit-esm/web-resources/styled-components.js";
import { ClearButton } from "/apps/websight-admin/web-resources/Buttons.js";
import { colors } from "/apps/websight-admin/web-resources/theme.js";
import { debounce } from "/apps/websight-admin/web-resources/Utils.js";
import { LoadingWrapper } from "/apps/websight-admin/web-resources/Wrappers.js";
import { ResourceIcon } from "/apps/websight-admin/web-resources/Icons.js";
import ResourceService from "../services/ResourceService.js";
import ResourceProviderDotMarkerContainer from "../utils/ResourceProviderDotMarkerContainer.js";
const ARROW_UP_KEY = 'ArrowUp';
const ARROW_DOWN_KEY = 'ArrowDown';
const ENTER_KEY = 'Enter';
const QUICK_SEARCH_SELECTED_ROW_CLASS = 'quick-search-selected';
const SearchContainer = styled.div`
    margin-top: 10px;
    width: 100%;
`;
const SearchFieldContainer = styled.div`
    display: flex;
    align-items: center;
    margin-bottom: 10px;
    && > div {
        max-width: 600px;
        border-width: 1px;
    }
`;
const SearchResultsContainer = styled.div`
    width: 100%;
    height: calc(100% - 52px);
    overflow-y: auto;
    border: 1px solid ${colors.mediumLightGrey};
    border-radius: 3px;

    &:focus {
        outline: none;
    }
`;
const SearchResultRowContainer = styled.div`
    align-items: center;
    border-bottom: 1px solid ${colors.mediumLightGrey};
    cursor: pointer;
    display: flex;
    font-size: 12px;
    padding: 6px;
    word-break: break-all;

    span {
        color: ${colors.primaryBlue};
    }

    mark {
        background: unset;
        color: unset;
        font-weight: bold;
    }

    .chevron {
        visibility: hidden;
    }

    &.${QUICK_SEARCH_SELECTED_ROW_CLASS} {
        background: ${colors.veryLightGrey};

        .chevron {
            visibility: visible;
        }
    }
`;
const NoResultsContainer = styled.div`
    display: flex;
    align-items: center;
    justify-content: center;
    height: calc(100% - 52px);
    font-size: 12px;
`;
const LaunchIcon = styled.i`
    font-size: 14px;
    padding: 5px 5px 5px 10px;
    color: ${colors.darkGrey};
`;
const WarningIcon = styled.i`
    font-size: 14px;
    color: ${colors.orange};
    margin: 4px 12px;
`;
export default class ResourceQuickSearch extends React.Component {
  constructor(props) {
    super(props);
    this.requestResourceSearch = this.requestResourceSearch.bind(this);
    this.resourcePathRender = this.resourcePathRender.bind(this);
    this.foundResourceRender = this.foundResourceRender.bind(this);
    this.scrollToResourceRow = this.scrollToResourceRow.bind(this);
    this.setQuickSearchProps = this.setQuickSearchProps.bind(this);
    this.noResultsRender = this.noResultsRender.bind(this);
  }

  componentDidUpdate(prevProps) {
    const {
      selectedProviders,
      quickSearch
    } = this.props;

    if (prevProps.selectedProviders.length !== selectedProviders.length) {
      this.onFieldChange(quickSearch.searchValue);
    }
  }

  setQuickSearchProps(props, callback) {
    const {
      quickSearch
    } = this.props;
    this.props.onQuickSearchChange({ ...quickSearch,
      ...props
    }, callback);
  }

  requestResourceSearch(value) {
    ResourceService.findResources(value, this.props.selectedProviders, (resources, data) => {
      this.setQuickSearchProps({
        foundResources: resources,
        warnings: Object.values(data).map(provider => provider.warning),
        selectedResourceIndex: 0,
        isLoading: false
      });
    }, () => this.setQuickSearchProps({
      foundResources: [],
      isLoading: false
    }));
  }

  openResource(index = this.props.quickSearch.selectedResourceIndex) {
    const {
      foundResources
    } = this.props.quickSearch;
    const {
      path,
      providers
    } = foundResources[index];

    if (!isNaN(index)) {
      this.setQuickSearchProps({
        selectedResourceIndex: index
      });
    }

    this.props.openResourcesForPath(path, providers[0].value);
  }

  scrollToResourceRow() {
    const el = document.querySelector(`.${QUICK_SEARCH_SELECTED_ROW_CLASS}`);
    el && el.scrollIntoView({
      block: 'end'
    });
  }

  onFieldChange(value) {
    this.setQuickSearchProps({
      searchValue: value,
      isLoading: true
    });
    this.debounceTimerId = debounce(() => this.requestResourceSearch(value), this.debounceTimerId);
  }

  onFieldKeyDown(key, event) {
    const {
      selectedResourceIndex,
      foundResources
    } = this.props.quickSearch;

    switch (key) {
      case ARROW_DOWN_KEY:
        event.preventDefault();

        if (selectedResourceIndex === foundResources.length - 1) {
          this.setQuickSearchProps({
            selectedResourceIndex: 0
          }, this.scrollToResourceRow);
        } else {
          this.setQuickSearchProps({
            selectedResourceIndex: selectedResourceIndex + 1
          }, this.scrollToResourceRow);
        }

        break;

      case ARROW_UP_KEY:
        event.preventDefault();

        if (selectedResourceIndex === 0) {
          this.setQuickSearchProps({
            selectedResourceIndex: foundResources.length - 1
          }, this.scrollToResourceRow);
        } else {
          this.setQuickSearchProps({
            selectedResourceIndex: selectedResourceIndex - 1
          }, this.scrollToResourceRow);
        }

        break;

      default:
        break;
    }
  }

  onFieldKeyUp(key) {
    switch (key) {
      case ENTER_KEY:
        this.openResource();
        break;

      default:
        break;
    }
  }

  resourcePathRender(path) {
    const {
      searchValue
    } = this.props.quickSearch;
    const terms = searchValue.split(/[/, ]+/).filter(term => term);
    let startIndex = 0;
    const highlightDetails = [];
    terms.forEach(term => {
      const termBegin = startIndex + path.substring(startIndex).indexOf(term);

      if (termBegin >= startIndex) {
        const termEnd = termBegin + term.length;
        highlightDetails.push({
          begin: startIndex,
          end: termBegin,
          highlight: false
        });
        startIndex = termEnd;
        highlightDetails.push({
          begin: termBegin,
          end: termEnd,
          highlight: true
        });
      }
    });
    highlightDetails.push({
      begin: startIndex,
      end: path.length,
      highlight: false
    });
    return /*#__PURE__*/React.createElement("span", null, terms.length ? highlightDetails.map(({
      begin,
      end,
      highlight
    }) => {
      const part = path.substring(begin, end);
      return highlight ? /*#__PURE__*/React.createElement("mark", {
        key: begin
      }, part) : /*#__PURE__*/React.createElement("span", {
        key: begin
      }, part);
    }) : path);
  }

  foundResourceRender(resource, index) {
    const {
      onOpenResourcesEditor
    } = this.props;
    const {
      selectedResourceIndex
    } = this.props.quickSearch;
    return /*#__PURE__*/React.createElement(SearchResultRowContainer, {
      className: index === selectedResourceIndex ? QUICK_SEARCH_SELECTED_ROW_CLASS : '',
      onClick: () => this.openResource(index)
    }, /*#__PURE__*/React.createElement("i", {
      className: "material-icons-outlined chevron"
    }, "chevron_right"), /*#__PURE__*/React.createElement(ResourceIcon, {
      isFolder: resource.hasChildren
    }), this.resourcePathRender(resource.path), resource.providers.map(provider => /*#__PURE__*/React.createElement(ResourceProviderDotMarkerContainer, {
      key: provider.value,
      style: {
        background: provider.color
      }
    }, provider.label)), resource.hasContent && /*#__PURE__*/React.createElement(Tooltip, {
      content: "Open in editor"
    }, /*#__PURE__*/React.createElement(LaunchIcon, {
      className: "material-icons-outlined",
      onClick: event => {
        onOpenResourcesEditor(resource);
        event.stopPropagation();
      }
    }, "launch")));
  }

  noResultsRender() {
    const {
      searchValue
    } = this.props.quickSearch;
    return /*#__PURE__*/React.createElement(React.Fragment, null, searchValue && /*#__PURE__*/React.createElement(NoResultsContainer, null, "No results found for '", searchValue, "'"));
  }

  warningMessagesRender(warnings) {
    if (warnings && warnings.length) {
      return /*#__PURE__*/React.createElement(React.Fragment, null, warnings.map((warningMessage, index) => /*#__PURE__*/React.createElement(Tooltip, {
        key: index,
        content: warningMessage,
        delay: 0
      }, /*#__PURE__*/React.createElement(WarningIcon, {
        className: "material-icons"
      }, "warning"))));
    }
  }

  render() {
    const {
      searchValue,
      foundResources,
      isLoading,
      warnings
    } = this.props.quickSearch;
    const keyEventHandlers = {
      onKeyUp: event => this.onFieldKeyUp(event.key),
      onKeyDown: event => this.onFieldKeyDown(event.key, event)
    };
    return /*#__PURE__*/React.createElement(SearchContainer, null, /*#__PURE__*/React.createElement(SearchFieldContainer, null, /*#__PURE__*/React.createElement(TextField, _extends({
      isCompact: true,
      placeholder: "Start typing to find resources",
      autocomplete: "off"
    }, keyEventHandlers, {
      onChange: event => this.onFieldChange(event.target.value),
      elemAfterInput: /*#__PURE__*/React.createElement(ClearButton, {
        onClick: () => this.setQuickSearchProps({
          searchValue: '',
          foundResources: []
        }),
        isVisible: searchValue
      }),
      value: searchValue
    })), this.warningMessagesRender(warnings)), /*#__PURE__*/React.createElement(SearchResultsContainer, _extends({
      className: "results"
    }, keyEventHandlers, {
      tabIndex: 0
    }), /*#__PURE__*/React.createElement(LoadingWrapper, {
      isLoading: isLoading,
      spinnerStyle: {
        top: '15vh',
        bottom: 'auto'
      },
      showSpinner: true
    }, foundResources.map(this.foundResourceRender)), !foundResources.length && !isLoading && this.noResultsRender()));
  }

}