import React from "/apps/websight-atlaskit-esm/web-resources/react.js";
import DropdownMenu, { DropdownItem } from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/dropdown-menu.js";
import { Cell, Row } from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/table-tree.js";
import Tooltip from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/tooltip.js";
import { TableRowActionButton } from "/apps/websight-admin/web-resources/Buttons.js";
import ConfirmationModal from "/apps/websight-admin/web-resources/ConfirmationModal.js";
import { TableRowActionButtonsContainer } from "/apps/websight-admin/web-resources/Containers.js";
import { WhiteTooltip } from "/apps/websight-admin/web-resources/Tooltips.js";
import AuthorizablesTags from "./AuthorizablesTags.js";
import GroupFormModal from "./GroupFormModal.js";
import GroupService from "../services/GroupService.js";
import AuthorizableName from "./AuthorizableName.js";
import { fetchApplicableActions } from "/apps/websight-admin/web-resources/utils/ExtraActionsUtil.js";

const groupName = group => group.displayName ? group.displayName : group.id;

export default class GroupRow extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      extraActions: props.extraActions
    };
    this.deleteGroup = this.deleteGroup.bind(this);
  }

  deleteGroup() {
    const {
      group
    } = this.props;
    GroupService.deleteGroup({
      id: group.id
    }, () => {
      if (this.props.onAuthorizableAction) {
        this.props.onAuthorizableAction('delete', group);
      }

      this.props.onUpdate();
    });
  }

  editButton() {
    const {
      group
    } = this.props;
    return /*#__PURE__*/React.createElement(TableRowActionButton, {
      tooltipContent: "Edit",
      iconClassName: "material-icons",
      iconName: "edit",
      onClick: () => {
        this.groupEditModal.open();

        if (this.props.onAuthorizableAction) {
          this.props.onAuthorizableAction('read', group);
        }
      }
    });
  }

  actionButtons() {
    const {
      extraActions
    } = this.state;
    return /*#__PURE__*/React.createElement(TableRowActionButtonsContainer, null, this.editButton(), /*#__PURE__*/React.createElement(DropdownMenu, {
      trigger: "",
      triggerType: "button",
      onOpenChange: event => {
        if (event.isOpen) {
          fetchApplicableActions(this.props.extraActions, this.props.group.path, actions => {
            this.setState({
              extraActions: actions
            });
          });
        }
      }
    }, extraActions && extraActions.map((action, index) => {
      return /*#__PURE__*/React.createElement(DropdownItem, {
        key: index,
        onClick: () => action.onClick(this.props.group.path)
      }, action.label);
    }), /*#__PURE__*/React.createElement(DropdownItem, {
      onClick: () => this.deleteConfirmationModal.open()
    }, "Delete")), extraActions && extraActions.map(action => {
      return action.modal(this.props.group);
    }), /*#__PURE__*/React.createElement(ConfirmationModal, {
      buttonText: 'Delete',
      heading: 'Delete group',
      appearance: "danger",
      message: /*#__PURE__*/React.createElement("span", null, "Are you sure you want to permanently delete ", /*#__PURE__*/React.createElement("b", null, groupName(this.props.group)), "?"),
      onConfirm: this.deleteGroup,
      ref: element => this.deleteConfirmationModal = element
    }));
  }

  render() {
    const {
      group,
      onUpdate
    } = this.props;

    const groupRowCells = () => [/*#__PURE__*/React.createElement(Cell, {
      key: `${group.id}-name`
    }, /*#__PURE__*/React.createElement(AuthorizableName, {
      authorizable: group,
      icon: "group"
    })), /*#__PURE__*/React.createElement(Cell, {
      singleLine: true,
      key: `${group.id}-id`
    }, group.id), /*#__PURE__*/React.createElement(Cell, {
      key: `${group.id}-parentGroups`
    }, /*#__PURE__*/React.createElement(AuthorizablesTags, {
      authorizables: this.props.group.parentGroups,
      expandable: true
    })), /*#__PURE__*/React.createElement(Cell, {
      key: `${group.id}-members`
    }, /*#__PURE__*/React.createElement(AuthorizablesTags, {
      authorizableId: group.id,
      authorizables: this.props.group.members,
      expandable: true
    })), /*#__PURE__*/React.createElement(Cell, {
      singleLine: true,
      key: `${group.id}-description`
    }, /*#__PURE__*/React.createElement(Tooltip, {
      component: WhiteTooltip,
      content: group.description,
      delay: 0
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        whiteSpace: 'nowrap',
        textOverflow: 'ellipsis',
        overflow: 'hidden'
      }
    }, group.description))), /*#__PURE__*/React.createElement(Cell, {
      singleLine: true,
      key: `${group.id}-buttons`
    }, this.actionButtons()), /*#__PURE__*/React.createElement(GroupFormModal, {
      key: `${group.id}-modal`,
      ref: element => this.groupEditModal = element,
      onSaveSuccess: data => {
        onUpdate();

        if (this.props.onAuthorizableAction) {
          this.props.onAuthorizableAction('edit', data);
        }
      },
      create: false,
      group: group
    })];

    return /*#__PURE__*/React.createElement(Row, {
      key: group.id,
      itemId: group.id
    }, groupRowCells());
  }

}