import React from "/apps/websight-atlaskit-esm/web-resources/react.js";
import Select, { CheckboxSelect } from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/select.js";
import { FilterOptionsContainer, FilterPatternContainer, FilterSortByContainer, HeaderFiltersContainer } from "/apps/websight-admin/web-resources/Containers.js";
import GroupAutosuggestion from "/apps/websight-autosuggestion-esm/web-resources/GroupAutosuggestion.js";
import { debounce } from "/apps/websight-admin/web-resources/Utils.js";
import StatefulFilterInput from "/apps/websight-admin/web-resources/components/StatefulFilterInput.js";
const filterOptions = [{
  label: 'Enabled',
  value: 'enabled',
  params: {
    enabled: true
  }
}, {
  label: 'Disabled',
  value: 'disabled',
  params: {
    enabled: false
  }
}, {
  label: 'Ever logged In',
  value: 'everLoggedIn',
  params: {
    everLoggedIn: true
  }
}, {
  label: 'Never logged In',
  value: 'neverLoggedIn',
  params: {
    everLoggedIn: false
  }
}];
const clearedFilterOptionsValues = {
  enabled: undefined,
  everLoggedIn: undefined
};
const sortByOptions = [{
  label: 'Username [A-Z]',
  value: {
    sortBy: 'id',
    sortDirection: 'ASC'
  }
}, {
  label: 'Username [Z-A]',
  value: {
    sortBy: 'id',
    sortDirection: 'DESC'
  }
}, {
  label: 'Last name [A-Z]',
  value: {
    sortBy: 'lastName',
    sortDirection: 'ASC'
  }
}, {
  label: 'Last name [Z-A]',
  value: {
    sortBy: 'lastName',
    sortDirection: 'DESC'
  }
}, {
  label: 'Logins count [0-9]',
  value: {
    sortBy: 'loginCount',
    sortDirection: 'ASC'
  }
}, {
  label: 'Logins count [9-0]',
  value: {
    sortBy: 'loginCount',
    sortDirection: 'DESC'
  }
}, {
  label: 'Last logged in [0-9]',
  value: {
    sortBy: 'lastLoggedIn',
    sortDirection: 'ASC'
  }
}, {
  label: 'Last logged in [9-0]',
  value: {
    sortBy: 'lastLoggedIn',
    sortDirection: 'DESC'
  }
}];
export default class UserHeaderBottomBar extends React.Component {
  constructor(props) {
    super(props);
    this.onChange = this.onChange.bind(this);
  }

  onChange(props) {
    this.props.onParamsChange(props);
  }

  get sortByValue() {
    return sortByOptions.find(option => option.value.sortBy === this.props.params.sortBy && option.value.sortDirection === this.props.params.sortDirection);
  }

  get filterOptionsValue() {
    return filterOptions.filter(option => {
      const isEnabled = option.params.enabled !== undefined && option.params.enabled === this.props.params.enabled;
      const everLoggedIn = option.params.everLoggedIn !== undefined && option.params.everLoggedIn === this.props.params.everLoggedIn;
      return isEnabled || everLoggedIn;
    });
  }

  render() {
    const {
      params
    } = this.props;
    return /*#__PURE__*/React.createElement(HeaderFiltersContainer, null, /*#__PURE__*/React.createElement(FilterPatternContainer, null, /*#__PURE__*/React.createElement(StatefulFilterInput, {
      onClear: () => {
        this.onChange({
          filter: ''
        });
      },
      onChange: event => {
        const targetValue = event.target.value;
        this.debounceFilterTimerId = debounce(() => this.onChange({
          filter: targetValue
        }), this.debounceFilterTimerId);
      },
      value: params.filter
    })), /*#__PURE__*/React.createElement(FilterOptionsContainer, null, /*#__PURE__*/React.createElement(GroupAutosuggestion, {
      value: params.groups,
      isMulti: true,
      spacing: "compact",
      placeholder: "In group",
      onChange: selectedOptions => {
        this.onChange({
          groups: selectedOptions || []
        });
      }
    })), /*#__PURE__*/React.createElement(FilterOptionsContainer, null, /*#__PURE__*/React.createElement(CheckboxSelect, {
      isMulti: true,
      isSearchable: false,
      options: filterOptions,
      onChange: selectedOptions => {
        const selectedParams = {};

        if (selectedOptions && selectedOptions.length) {
          Object.assign(selectedParams, ...selectedOptions.map(option => option.params));
        }

        this.onChange({ ...clearedFilterOptionsValues,
          ...selectedParams
        });
      },
      placeholder: "Choose an option",
      spacing: "compact",
      value: this.filterOptionsValue
    })), /*#__PURE__*/React.createElement(FilterSortByContainer, null, /*#__PURE__*/React.createElement(Select, {
      placeholder: "Sort By",
      spacing: "compact",
      options: sortByOptions,
      value: this.sortByValue,
      onChange: selectedOption => {
        this.onChange({ ...selectedOption.value
        });
      }
    })));
  }

}