import React from "/apps/websight-atlaskit-esm/web-resources/react.js";
import { Cell, Row } from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/table-tree.js";
import styled from "/apps/websight-atlaskit-esm/web-resources/styled-components.js";
import Tooltip from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/tooltip.js";
import { TableRowActionButton } from "/apps/websight-admin/web-resources/Buttons.js";
import ConfirmationModal from "/apps/websight-admin/web-resources/ConfirmationModal.js";
import { TableRowActionButtonsContainer } from "/apps/websight-admin/web-resources/Containers.js";
import { colors } from "/apps/websight-admin/web-resources/theme.js";
import ContentTag from "/apps/websight-admin/web-resources/components/ContentTag.js";
import LabelValueTable from "/apps/websight-admin/web-resources/components/LabelValueTable.js";
import { WhiteTooltip } from "/apps/websight-admin/web-resources/Tooltips.js";
import PermissionsService from "../../services/PermissionsService.js";
import EditAcEntryModal from "./AccessControlEntryModal.js";
const REP_GLOB = 'rep:glob';
const permissionTypeDotStyle = {
  fontSize: '14px',
  verticalAlign: 'text-bottom',
  marginRight: '6px'
};
const headerIconStyle = {
  fontSize: '22px',
  verticalAlign: 'middle',
  paddingRight: '5px',
  color: colors.grey
};
const HierarchyTooltipIcon = styled.i`
    font-size: 21px;
    margin-left: 8px;
    margin-top: 3px;
    color: ${colors.grey};
    cursor: pointer;
`;
const TableSectionHeaderContainer = styled.div`
    width: 100%;
    height: 50px;
    display: flex;
    justify-content: flex-start;
    align-items: center;
`;

const PermissionType = props => {
  const {
    allow
  } = props;
  const text = allow ? 'allow' : 'deny';
  const color = allow ? colors.green : colors.red;
  return /*#__PURE__*/React.createElement("div", {
    style: {
      display: 'inline-block'
    }
  }, /*#__PURE__*/React.createElement("i", {
    className: "material-icons",
    style: { ...permissionTypeDotStyle,
      color: color
    }
  }, "fiber_manual_record"), text);
};

const Privileges = props => {
  const {
    privileges = []
  } = props;
  return /*#__PURE__*/React.createElement(React.Fragment, null, privileges.map(privilege => /*#__PURE__*/React.createElement("div", {
    key: privilege
  }, /*#__PURE__*/React.createElement(ContentTag, null, privilege))));
};

const Restrictions = props => {
  const {
    restrictions = {}
  } = props;

  const appendRestriction = (restrictionsString, key, value) => {
    let newRestrictions = restrictionsString;

    if (newRestrictions) {
      newRestrictions += ', ';
    }

    newRestrictions += `"${value}"`;
    return newRestrictions;
  };

  return /*#__PURE__*/React.createElement("span", null, Object.entries(restrictions).map(([type, value]) => {
    let stringValue = '';

    if (value instanceof Array) {
      value.forEach(arrayValue => {
        stringValue = appendRestriction(stringValue, type, arrayValue);
      });

      if (type !== REP_GLOB) {
        stringValue = '[' + stringValue + ']';
      }
    } else {
      stringValue = appendRestriction(stringValue, type, value);
    }

    return /*#__PURE__*/React.createElement("span", {
      key: type
    }, /*#__PURE__*/React.createElement("b", null, type), "=", stringValue, /*#__PURE__*/React.createElement("br", null));
  }));
};

export default class AceRow extends React.Component {
  constructor(props) {
    super(props);
    this.deleteAcEntry = this.deleteAcEntry.bind(this);
  }

  deleteAcEntry(entry) {
    PermissionsService.deleteAclEntry({
      authorizableId: this.props.authorizableId,
      entryId: entry.entryId,
      policyId: entry.policyId
    }, () => {
      this.deleteConfirmationModal.close();
      this.props.onUpdate();
    }, () => {
      this.deleteConfirmationModal.close();
    });
  }

  cells(entry) {
    let cellsArray = [/*#__PURE__*/React.createElement(Cell, {
      key: "path"
    }, /*#__PURE__*/React.createElement("span", {
      style: {
        overflowWrap: 'anywhere'
      }
    }, entry.path)), /*#__PURE__*/React.createElement(Cell, {
      key: "type",
      singleLine: true
    }, /*#__PURE__*/React.createElement(PermissionType, {
      allow: entry.allow
    })), /*#__PURE__*/React.createElement(Cell, {
      key: "privileges"
    }, /*#__PURE__*/React.createElement(Privileges, {
      privileges: entry.privileges
    })), /*#__PURE__*/React.createElement(Cell, {
      key: "restrictions"
    }, /*#__PURE__*/React.createElement(Restrictions, {
      restrictions: entry.restrictions
    }))];

    if (!this.props.isReadOnly) {
      cellsArray = [...cellsArray, /*#__PURE__*/React.createElement(Cell, {
        key: "actions",
        singleLine: true
      }, this.actionButtons(entry))];
    }

    return cellsArray;
  }

  actionButtons(entry) {
    return /*#__PURE__*/React.createElement(TableRowActionButtonsContainer, null, /*#__PURE__*/React.createElement(TableRowActionButton, {
      tooltipContent: "Edit",
      iconClassName: "material-icons",
      iconName: "edit",
      onClick: () => this.editAcEntryModal.open()
    }), /*#__PURE__*/React.createElement(TableRowActionButton, {
      tooltipContent: "Delete",
      iconClassName: "material-icons",
      iconName: "close",
      onClick: () => this.deleteConfirmationModal.open()
    }), /*#__PURE__*/React.createElement(EditAcEntryModal, {
      ref: element => this.editAcEntryModal = element,
      authorizableId: this.props.authorizableId,
      entryToEdit: entry,
      onSaveSuccess: this.props.onUpdate
    }), /*#__PURE__*/React.createElement(ConfirmationModal, {
      buttonText: 'Delete',
      heading: 'Delete Access Control Entry',
      appearance: "danger",
      message: this.deleteConfirmationContent(entry),
      onConfirm: () => this.deleteAcEntry(entry),
      ref: element => this.deleteConfirmationModal = element
    }));
  }

  deleteConfirmationContent(entry) {
    const entryData = [{
      label: 'Authorizable ID',
      value: this.props.authorizableId
    }, {
      label: 'Path',
      value: entry.path
    }, {
      label: 'Permission Type',
      value: /*#__PURE__*/React.createElement(PermissionType, {
        allow: entry.allow
      })
    }, {
      label: 'Privileges',
      value: /*#__PURE__*/React.createElement(Privileges, {
        privileges: entry.privileges
      })
    }, {
      label: 'Restrictions',
      value: /*#__PURE__*/React.createElement(Restrictions, {
        restrictions: entry.restrictions
      })
    }];
    return /*#__PURE__*/React.createElement(React.Fragment, null, "Are you sure you want to delete this Access Control Entry?", /*#__PURE__*/React.createElement(LabelValueTable, {
      data: entryData,
      labelWidth: "120px"
    }));
  }

  hierarchyTooltipContent(sectionHeader, hierarchy) {
    return /*#__PURE__*/React.createElement(React.Fragment, null, "Hierarchy: ", [sectionHeader, ...hierarchy].join(' \u2192 '));
  }

  render() {
    const {
      entry
    } = this.props;
    const {
      sectionHeader,
      sectionHierarchy
    } = entry;
    return /*#__PURE__*/React.createElement(Row, {
      key: entry.path,
      itemId: entry.path
    }, sectionHeader ? /*#__PURE__*/React.createElement(TableSectionHeaderContainer, null, /*#__PURE__*/React.createElement("span", {
      style: {
        paddingLeft: '25px'
      }
    }, /*#__PURE__*/React.createElement("i", {
      className: "material-icons",
      style: headerIconStyle
    }, "people"), sectionHeader), sectionHierarchy && sectionHierarchy.length > 0 && /*#__PURE__*/React.createElement(Tooltip, {
      component: WhiteTooltip,
      tag: "span",
      content: this.hierarchyTooltipContent(sectionHeader, sectionHierarchy)
    }, /*#__PURE__*/React.createElement(HierarchyTooltipIcon, {
      className: "material-icons"
    }, "info_outline"))) : this.cells(entry));
  }

}