import React from "/apps/websight-atlaskit-esm/web-resources/react.js";
import Button, { ButtonGroup } from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/button.js";
import Pagination from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/pagination.js";
import PageHeader from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/page-header.js";
import Breadcrumbs from "/apps/websight-admin/web-resources/Breadcrumbs.js";
import { LoadingWrapper } from "/apps/websight-admin/web-resources/Wrappers.js";
import { PaginationContainer } from "/apps/websight-admin/web-resources/Containers.js";
import TableItemsCountInfo from "/apps/websight-admin/web-resources/components/TableItemsCountInfo.js";
import { getUrlParamValues, setUrlParamValues } from "/apps/websight-admin/web-resources/services/SearchParamsService.js";
import { AUTH_CONTEXT_UPDATED } from "/apps/websight-rest-atlaskit-client/web-resources/js/RestClient.js";
import GroupFormModal from "../components/GroupFormModal.js";
import GroupHeaderBottomBar from "../components/GroupHeaderBottomBar.js";
import GroupsTable from "../components/GroupsTable.js";
import GroupService from "../services/GroupService.js";
import { USER_MANAGER_ROOT_PATH } from "../utils/UserManagerConstants.js";
import { arrayToAutosuggestionOptions, autosuggestionOptionsToArray } from "../utils/AutosuggestionUtil.js";

const calculatePages = pagesCount => {
  return pagesCount ? [...Array(pagesCount).keys()].map(x => x + 1) : [];
};

export default class GroupsPage extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      groups: [],
      numberOfFoundGroups: null,
      numberOfPages: 0,
      isLoadingGroups: false,
      params: {
        pageNumber: 1
      },
      requestedParams: {},
      loadedParams: {}
    };
    this.onHashChange = this.onHashChange.bind(this);
    this.onPageChange = this.onPageChange.bind(this);
    this.refreshGroups = this.refreshGroups.bind(this);
    this.onParamsChange = this.onParamsChange.bind(this);
  }

  componentDidMount() {
    window.addEventListener('hashchange', this.onHashChange);
    this.loadDataFromUrl();
    window.addEventListener(AUTH_CONTEXT_UPDATED, () => {
      this.loadDataFromUrl();
    });
  }

  componentDidUpdate(prevProps, prevState) {
    const {
      params
    } = this.state;

    if (JSON.stringify(params) !== JSON.stringify(prevState.params)) {
      const pageNumber = params.pageNumber > 1 ? params.pageNumber : undefined;
      const urlParamsConfig = {
        parentGroups: {
          separator: '|'
        },
        members: {
          separator: '|'
        }
      };
      const filterParams = { ...this.state.params,
        pageNumber: pageNumber,
        parentGroups: autosuggestionOptionsToArray(this.state.params.parentGroups),
        members: autosuggestionOptionsToArray(this.state.params.members)
      };
      setUrlParamValues(filterParams, urlParamsConfig);
    }
  }

  componentWillUnmount() {
    window.removeEventListener('hashchange', this.onHashChange);
  }

  onHashChange() {
    this.loadDataFromUrl();
  }

  loadDataFromUrl() {
    const paramsConfig = {
      parentGroups: {
        isArray: true,
        separator: '|'
      },
      members: {
        isArray: true,
        separator: '|'
      },
      pageNumber: {
        type: 'number'
      }
    };
    const params = getUrlParamValues(['filter', 'parentGroups', 'members', 'pageNumber', 'sortBy', 'sortDirection'], paramsConfig);
    this.onParamsChange({ ...params,
      parentGroups: arrayToAutosuggestionOptions(params.parentGroups),
      members: arrayToAutosuggestionOptions(params.members)
    });
  }

  getGroups() {
    if (this.state.isLoadingGroups) return;

    const onSuccess = (data = {
      groups: []
    }) => {
      this.setState(prevState => ({
        isLoadingGroups: false,
        loadedParams: prevState.requestedParams,
        numberOfFoundGroups: data.numberOfFoundGroups || 0,
        numberOfPages: data.numberOfPages,
        requestedParams: {},
        groups: data.groups
      }), () => {
        if (JSON.stringify(this.state.loadedParams) !== JSON.stringify(this.state.params)) {
          this.getGroups();
        }
      });
    };

    const onFailure = () => this.setState(prevState => ({
      isLoadingGroups: false,
      params: prevState.loadedParams,
      requestedParams: {}
    }));

    this.setState(prevState => ({
      isLoadingGroups: true,
      requestedParams: prevState.params
    }), () => GroupService.getGroups(this.state.params, onSuccess, onFailure));
  }

  refreshGroups() {
    this.getGroups();
  }

  onPageChange(event, newPage) {
    this.setState(prevState => ({
      params: { ...prevState.params,
        pageNumber: newPage
      }
    }), () => this.getGroups());
  }

  onParamsChange(params) {
    const pageNumber = params.pageNumber ? params.pageNumber : 1;
    this.setState(prevState => ({
      params: { ...prevState.params,
        ...params,
        pageNumber: pageNumber
      }
    }), () => this.getGroups());
  }

  render() {
    const actions = /*#__PURE__*/React.createElement(ButtonGroup, null, /*#__PURE__*/React.createElement(Button, {
      onClick: () => this.groupCreateModal.open()
    }, "Create Group"));
    return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(PageHeader, {
      actions: actions,
      bottomBar: /*#__PURE__*/React.createElement(GroupHeaderBottomBar, {
        onParamsChange: this.onParamsChange,
        params: this.state.params
      }),
      breadcrumbs: /*#__PURE__*/React.createElement(Breadcrumbs, {
        breadcrumbs: [{
          text: 'User Manager',
          path: USER_MANAGER_ROOT_PATH,
          reactPath: ''
        }, {
          text: 'Groups',
          reactPath: '/groups'
        }]
      })
    }, "Groups"), /*#__PURE__*/React.createElement(TableItemsCountInfo, {
      isHidden: this.state.numberOfFoundGroups === null,
      itemName: "group",
      numberOfFoundItems: this.state.numberOfFoundGroups
    }), /*#__PURE__*/React.createElement(GroupsTable, {
      groups: this.state.groups,
      isLoading: this.state.isLoadingGroups,
      isInitialized: this.state.numberOfFoundGroups != null,
      refreshGroups: this.refreshGroups,
      onAuthorizableAction: this.props.onAuthorizableAction,
      extraActions: this.props.extraActions
    }), this.state.numberOfPages > 1 && /*#__PURE__*/React.createElement(PaginationContainer, null, /*#__PURE__*/React.createElement(LoadingWrapper, {
      isLoading: this.state.isLoadingGroups
    }, /*#__PURE__*/React.createElement(Pagination, {
      pages: calculatePages(this.state.numberOfPages),
      selectedIndex: this.state.params.pageNumber - 1,
      onChange: this.onPageChange
    }))), /*#__PURE__*/React.createElement(GroupFormModal, {
      ref: element => this.groupCreateModal = element,
      onSaveSuccess: data => {
        this.refreshGroups();

        if (this.props.onAuthorizableAction) {
          this.props.onAuthorizableAction('create', data);
        }
      },
      create: true
    }));
  }

}