import React from "/apps/websight-atlaskit-esm/web-resources/react.js";
import { Redirect } from "/apps/websight-atlaskit-esm/web-resources/react-router-dom.js";
import Button from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/button.js";
import Tabs from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/tabs.js";
import PageHeader from "/apps/websight-atlaskit-esm/web-resources/@atlaskit/page-header.js";
import Breadcrumbs from "/apps/websight-admin/web-resources/Breadcrumbs.js";
import ConfirmationModal from "/apps/websight-admin/web-resources/ConfirmationModal.js";
import { colors } from "/apps/websight-admin/web-resources/theme.js";
import UserDetailsGeneral from "../components/UserDetailsGeneral.js";
import UserFormModal from "../components/UserFormModal.js";
import AdvancedPermissions from "../components/permissions/AdvancedPermissions.js";
import BasicPermissions from "../components/permissions/BasicPermissions.js";
import UserService from "../services/UserService.js";
import { getAuthorizableDisplayName, getTabIndex, setTabNameInHash } from "../utils/AuthorizableUtil.js";
import { USER_MANAGER_ROOT_PATH } from "../utils/UserManagerConstants.js";
const headerIconStyle = {
  fontSize: '31px',
  verticalAlign: 'bottom',
  paddingRight: '5px',
  color: colors.grey
};
export default class UserDetailsPage extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      currentTabIndex: 0,
      tabIndexToConfirm: null,
      redirect: false,
      user: { ...UserService.emptyUserData
      }
    };
    this.getUser = this.getUser.bind(this);
    this.onHashChange = this.onHashChange.bind(this);
    this.setUserFromResponseData = this.setUserFromResponseData.bind(this);
    this.changeTab = this.changeTab.bind(this);
    this.checkIfCurrentTabDataChanged = this.checkIfCurrentTabDataChanged.bind(this);
  }

  componentDidMount() {
    window.addEventListener('hashchange', this.onHashChange);
    this.loadDataFromUrl();
  }

  componentWillUnmount() {
    window.removeEventListener('hashchange', this.onHashChange);
  }

  onHashChange() {
    this.loadDataFromUrl();
  }

  loadDataFromUrl() {
    this.getUser();
  }

  setTabInHash(tabIndex) {
    setTabNameInHash('users', this.props.match.params.userId, tabIndex);
  }

  getUser() {
    const params = {
      authorizableId: decodeURIComponent(this.props.match.params.userId)
    };
    const tabIndex = getTabIndex(this.props.match.params.tabName);
    this.setTabInHash(tabIndex);

    const onSuccess = data => {
      this.setState({
        user: data,
        currentTabIndex: tabIndex
      });

      if (this.props.onAuthorizableAction) {
        this.props.onAuthorizableAction('read', data);
      }
    };

    const onFailure = () => {
      if (this.props.onAuthorizableAction) {
        this.props.onAuthorizableAction('out-of-date-view', {
          id: params.authorizableId,
          type: 'user'
        });
      }

      this.setState({
        redirect: true
      });
    };

    UserService.getUser(params, onSuccess, onFailure);
  }

  setUserFromResponseData(data) {
    this.setState(prevState => ({
      user: { ...prevState.user,
        ...data
      }
    }));
  }

  checkIfCurrentTabDataChanged() {
    const basicPermissionsTab = 1;
    return this.state.currentTabIndex === basicPermissionsTab && this.basicPermissionsTab !== null && this.basicPermissionsTab.changesMade();
  }

  changeTab(changeConfirmed, destinationTabIndex = this.state.tabIndexToConfirm) {
    if (destinationTabIndex === this.state.currentTabIndex) {
      return;
    }

    if (changeConfirmed || !this.checkIfCurrentTabDataChanged()) {
      this.setState({
        currentTabIndex: destinationTabIndex,
        tabIndexToConfirm: null
      }, () => {
        this.changeTabConfirmationModal.close();
        this.setTabInHash(destinationTabIndex);
      });
    } else {
      this.setState({
        tabIndexToConfirm: destinationTabIndex
      }, this.changeTabConfirmationModal.open());
    }
  }

  render() {
    const {
      currentTabIndex,
      redirect,
      user
    } = this.state;
    const tabs = [{
      label: 'Details',
      content: /*#__PURE__*/React.createElement(UserDetailsGeneral, {
        user: user
      })
    }, {
      label: 'Permissions',
      content: /*#__PURE__*/React.createElement(BasicPermissions, {
        isAdmin: user.admin,
        authorizableId: user.id,
        ref: element => this.basicPermissionsTab = element,
        onAuthorizableAction: this.props.onAuthorizableAction,
        displayName: getAuthorizableDisplayName(user),
        type: user.type
      })
    }, {
      label: 'Advanced Permissions',
      content: /*#__PURE__*/React.createElement(AdvancedPermissions, {
        isAdmin: user.admin,
        authorizableId: user.id,
        onAuthorizableAction: this.props.onAuthorizableAction,
        displayName: getAuthorizableDisplayName(user),
        type: user.type
      })
    }];
    return /*#__PURE__*/React.createElement(React.Fragment, null, redirect && /*#__PURE__*/React.createElement(Redirect, {
      to: "/users"
    }), /*#__PURE__*/React.createElement(PageHeader, {
      actions: /*#__PURE__*/React.createElement(Button, {
        onClick: () => this.userEditModal.open()
      }, "Edit"),
      breadcrumbs: /*#__PURE__*/React.createElement(Breadcrumbs, {
        breadcrumbs: [{
          text: 'User Manager',
          path: USER_MANAGER_ROOT_PATH,
          reactPath: ''
        }, {
          text: 'Users',
          reactPath: '/users'
        }, {
          text: user.displayName,
          reactPath: `/users/${user.id}`
        }]
      })
    }, /*#__PURE__*/React.createElement("i", {
      className: "material-icons",
      style: headerIconStyle
    }, user.icon), user.enabled ? user.displayName : /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("del", null, user.displayName), "(disabled)")), /*#__PURE__*/React.createElement(UserFormModal, {
      ref: element => this.userEditModal = element,
      create: false,
      onSaveSuccess: data => {
        this.setUserFromResponseData(data);

        if (this.props.onAuthorizableAction) {
          this.props.onAuthorizableAction('edit', data);
        }
      },
      user: user
    }), /*#__PURE__*/React.createElement(ConfirmationModal, {
      buttonText: 'Change Tab',
      heading: 'Change Tab',
      appearance: "warning",
      message: /*#__PURE__*/React.createElement(React.Fragment, null, "You will lost all your unsaved changes. Are you sure you want change current tab?"),
      onConfirm: () => this.changeTab(true),
      ref: element => this.changeTabConfirmationModal = element
    }), /*#__PURE__*/React.createElement(Tabs, {
      tabs: tabs,
      selected: currentTabIndex,
      onSelect: (_tab, index) => this.changeTab(false, index)
    }));
  }

}